pub fn disclosure(section: &str) -> Option<Disclosure>Expand description
The disclosure rule for section, or None when it has no row and
must therefore be withheld.
pub fn disclosure(section: &str) -> Option<Disclosure>The disclosure rule for section, or None when it has no row and
must therefore be withheld.