pub fn validate_username(user: &str) -> Result<(), String>Expand description
Checks a name the node will interpolate into an authorized_keys
forced command and key on for every authorization decision.
Errors
Returns a message when the name is empty, too long, spelled with
anything but ASCII letters, digits, -, _ and ., reserved for the
unauthenticated placeholder, or spelled like an invite id.